# PsychoFit Graphing Script
# Lew Harvey
# 20 June 2014

# this script takes a graphics file produced by PsychoFit and
# produces one psychometric function graph per data set. Three things are plotted:
#	1. The original data points
#	2. The smooth function predicted by the fitted model
#	3. marker lines showing the value of the location parameter, alpha
#
# each data set is plotted following a prompt in the console window.
# You may also plot an individual data set by giving the plot1() command
# with the data set number as an argument

# rm(list = ls())

# plot psychometric function
#######################################################################
plot1 <- function(data.set.number = 1) {
	# make sure data.set.number is within range in data frame
	# if it is outside the range, it is set to 1
	if(data.set.number < 0 || data.set.number > totalNumberOfDataSets) {
		data.set.number <- 1}

	plot(predicted_probability ~ log_stimulus, data = df.predicted,
		type = "l",
		col = "blue",
		xlab = "log stimulus magnitude",
		ylab = "Probability",
		main = paste("Data Set", data.set.number, ": ", functionName, "Model"))
	points(observed_probability ~ log_stimulus, data = df.observed,
		pch = 19)
	lines(alpha_marker ~ log_stimulus, data = df.markers, col = "gray")
}


# main program loop
#######################################################################
#######################################################################

# Read in the PsychFit graphics file into a data frame
fn <- file.choose()							# choose the file to read
df.all <- read.delim(fn, header = TRUE)		# reads tab-delimited file
totalNumberOfDataSets <- length(levels(factor(df.all$data_set)))

# loop through the data sets
for (sn in 1:totalNumberOfDataSets)
{
	df <- subset(df.all, data_set == sn)	# select a data set
	functionName <- df$function_name[1]		# get function name
	df.observed  <- df[!is.na(df$observed_probability),  c("data_set", "log_stimulus", "stimulus", "observed_probability")]
	df.predicted <- df[!is.na(df$predicted_probability), c("data_set", "log_stimulus", "stimulus", "predicted_probability")]
	df.markers   <- df[!is.na(df$alpha_marker), c("data_set", "log_stimulus", "stimulus", "alpha_marker")]
	plot1(sn)
	if (totalNumberOfDataSets > 1) par(ask = TRUE)
	if (sn == totalNumberOfDataSets) par(ask = FALSE)
}